# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bbot',
 'bbot.agent',
 'bbot.core',
 'bbot.core.configurator',
 'bbot.core.event',
 'bbot.core.helpers',
 'bbot.core.helpers.cloud',
 'bbot.core.helpers.depsinstaller',
 'bbot.core.logger',
 'bbot.db',
 'bbot.modules',
 'bbot.modules.deadly',
 'bbot.modules.internal',
 'bbot.modules.output',
 'bbot.modules.report',
 'bbot.scanner',
 'bbot.test',
 'bbot.test.test_step_1',
 'bbot.test.test_step_2']

package_data = \
{'': ['*'], 'bbot': ['wordlists/*']}

install_requires = \
['ansible-runner>=2.2.0,<3.0.0',
 'ansible>=5.7.1,<6.0.0',
 'deepdiff>=5.8.1,<6.0.0',
 'dnspython>=2.2.1,<3.0.0',
 'omegaconf>=2.1.1,<3.0.0',
 'psutil>=5.9.0,<6.0.0',
 'pycryptodome>=3.15.0,<4.0.0',
 'pydantic>=1.9.0,<2.0.0',
 'requests-cache>=0.9.3,<0.10.0',
 'tabulate>=0.8.10,<0.9.0',
 'tldextract>=3.2.0,<4.0.0',
 'websocket-client>=1.3.2,<2.0.0',
 'wordninja>=2.0.0,<3.0.0',
 'xmltojson>=2.0.1,<3.0.0']

entry_points = \
{'console_scripts': ['bbot = bbot.cli:main']}

setup_kwargs = {
    'name': 'bbot',
    'version': '1.0.4.922',
    'description': 'OSINT automation for hackers.',
    'long_description': '![bbot_banner](https://user-images.githubusercontent.com/20261699/158000235-6c1ace81-a267-4f8e-90a1-f4c16884ebac.png)\n\n# BEE·bot\n### OSINT automation for hackers.\n\n~~~bash\npip install bbot\n~~~\n\n[![Python Version](https://img.shields.io/badge/python-3.9+-FF8400)](https://www.python.org) [![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![License](https://img.shields.io/badge/license-GPLv3-FF8400.svg)](https://github.com/blacklanternsecurity/bbot/blob/dev/LICENSE) [![Tests](https://github.com/blacklanternsecurity/bbot/actions/workflows/tests.yml/badge.svg?branch=stable)](https://github.com/blacklanternsecurity/bbot/actions?query=workflow%3A"tests") [![Codecov](https://codecov.io/gh/blacklanternsecurity/bbot/branch/dev/graph/badge.svg?token=IR5AZBDM5K)](https://codecov.io/gh/blacklanternsecurity/bbot)\n\n![subdomain demo](https://user-images.githubusercontent.com/20261699/182274919-d4f5aa69-993a-40aa-95d5-f5e69e96026c.gif)\n\n### **BBOT** is a **recursive**, **modular** OSINT framework inspired by Spiderfoot and written in Python.\n\nCapable of executing the entire OSINT process in a single command, BBOT does subdomain enumeration, port scanning, web screenshots (with its `gowitness` module), vulnerability scanning (with `nuclei`), and much more.\n\nBBOT currently has over **70 modules** and counting.\n\n### [Subdomain Enumeration Face-off](https://blog.blacklanternsecurity.com/p/subdomain-enumeration-tool-face-off)\n\n![graphs-small](https://user-images.githubusercontent.com/20261699/199602154-14c71a93-57aa-4ac0-ad81-87ce64fbffc7.png)\n\n## Installation (pip)\n~~~bash\n# note: installing in a virtualenv is recommended\npip install bbot\n\nbbot --help\n~~~\nPrerequisites:\n- Linux (Windows including WSL is not supported)\n- Python 3.9 or newer\n\n## [Installation (Docker)](https://hub.docker.com/r/blacklanternsecurity/bbot)\n~~~bash\n# bleeding edge (dev)\ndocker run -it blacklanternsecurity/bbot --help\n\n# stable\ndocker run -it blacklanternsecurity/bbot:stable --help\n\n# note: alternatively there is a helper script that will map docker volumes to persist your BBOT scan data:\n./bbot-docker.sh --help\n~~~\n\nIf you need help with installation, please refer to the [wiki](https://github.com/blacklanternsecurity/bbot/wiki#installation).\n\nSee also: [Release History](https://github.com/blacklanternsecurity/bbot/wiki/Release-History)\n\n## Scanning with BBOT\n\nNote: the `httpx` module is recommended in most scans because it is [used by BBOT to visit webpages](https://github.com/blacklanternsecurity/bbot/wiki#note-on-the-httpx-module).\n\n### Examples\n~~~bash\n# list modules\nbbot -l\n\n# subdomain enumeration\nbbot --flags subdomain-enum --modules httpx --targets evilcorp.com\n\n# passive modules only\nbbot --flags passive --targets evilcorp.com\n\n# web screenshots with gowitness\nbbot -m naabu httpx gowitness --name my_scan --output-dir . -t subdomains.txt\n\n# web scan\nbbot -f web-basic -t www.evilcorp.com\n\n# web spider (search for emails, etc.)\nbbot -m httpx -c web_spider_distance=2 web_spider_depth=2 -t www.evilcorp.com\n\n# everything at once because yes\nbbot -f subdomain-enum email-enum cloud-enum web-basic -m naabu gowitness nuclei --allow-deadly -t evilcorp.com\n~~~\n\n### Targets\n\nIn BBOT, targets are used to seed a scan. You can specify any number of targets, and if you require more granular control over scope, you can also use whitelists and blacklists.\n\n~~~bash\n# multiple targets\nbbot -t evilcorp.com evilcorp.co.uk 1.2.3.0/24 targets.txt\n\n# seed a scan with two domains, but only consider assets to be in scope if they are inside 1.2.3.0/24\nbbot -t evilcorp.com evilcorp.co.uk --whitelist 1.2.3.0/24 --blacklist test.evilcorp.com 1.2.3.4\n~~~\n\nVisit the wiki for more [tips and tricks](https://github.com/blacklanternsecurity/bbot/wiki#tips-and-tricks), including details on how BBOT handles scope, and how to tweak it if you need to.\n\n## Using BBOT as a Python library\n~~~python\nfrom bbot.scanner import Scanner\n\n# any number of targets can be specified\nscan = Scanner("evilcorp.com", "1.2.3.0/24", modules=["naabu"])\nfor event in scan.start():\n    print(event)\n~~~\n\n# Output\nBBOT can output to TXT, JSON, CSV, Neo4j, and more with `--output-module`. You can output to multiple formats simultaneously.\n~~~bash\n# tee to a file\nbbot -f subdomain-enum -t evilcorp.com | tee evilcorp.txt\n\n# output to JSON\nbbot --output-module json -f subdomain-enum -t evilcorp.com | jq\n\n# output to CSV, TXT, and JSON, in current directory\nbbot -o . --output-module human csv json -f subdomain-enum -t evilcorp.com\n~~~\nFor every scan, BBOT generates a unique and mildly-entertaining name like `fuzzy_gandalf`. Output for that scan, including the word cloud and any gowitness screenshots, etc., are saved to a folder by that name in `~/.bbot/scans`. The most recent 20 scans are kept, and older ones are removed. You can change the location of BBOT\'s output with `--output`, and you can also pick a custom scan name with `--name`.\n\nIf you reuse a scan name, it will append to its original output files and leverage the previous word cloud.\n\n# Neo4j\nNeo4j is the funnest (and prettiest) way to view and interact with BBOT data.\n\n![neo4j](https://user-images.githubusercontent.com/20261699/182398274-729f3c48-c23c-4db0-8c2e-8b403c1bf790.png)\n\n- You can get Neo4j up and running with a single docker command:\n~~~bash\ndocker run -p 7687:7687 -p 7474:7474 -v "$(pwd)/data/:/data/" --env NEO4J_AUTH=neo4j/bbotislife neo4j\n~~~\n- After that, run bbot with `--output-modules neo4j`\n~~~bash\nbbot -f subdomain-enum -t evilcorp.com --output-modules human neo4j\n~~~\n- Browse data at http://localhost:7474\n\n# Usage\n~~~\n$ bbot --help\nusage: bbot [-h] [--help-all] [-t TARGET [TARGET ...]] [-w WHITELIST [WHITELIST ...]] [-b BLACKLIST [BLACKLIST ...]] [--strict-scope] [-n SCAN_NAME] [-m MODULE [MODULE ...]] [-l] [-em MODULE [MODULE ...]]\n            [-f FLAG [FLAG ...]] [-rf FLAG [FLAG ...]] [-ef FLAG [FLAG ...]] [-om MODULE [MODULE ...]] [-o DIR] [-c [CONFIG ...]] [--allow-deadly] [-v] [-d] [-s] [--force] [-y] [--dry-run] [--current-config]\n            [--save-wordcloud FILE] [--load-wordcloud FILE] [--no-deps | --force-deps | --retry-deps | --ignore-failed-deps | --install-all-deps] [-a] [--version]\n\nBighuge BLS OSINT Tool\n\noptions:\n  -h, --help            show this help message and exit\n  --help-all            Display full help including module config options\n  -n SCAN_NAME, --name SCAN_NAME\n                        Name of scan (default: random)\n  -m MODULE [MODULE ...], --modules MODULE [MODULE ...]\n                        Modules to enable. Choices: affiliates,anubisdb,asn,aspnet_viewstate,azure_tenant,bevigil,binaryedge,bucket_aws,bucket_azure,bucket_gcp,builtwith,bypass403,c99,censys,certspotter,cookie_brute,crobat,crt,dnscommonsrv,dnsdumpster,dnszonetransfer,emailformat,ffuf,ffuf_shortnames,fullhunt,generic_ssrf,getparam_brute,github,gowitness,hackertarget,header_brute,host_header,httpx,hunt,hunterio,iis_shortnames,ipneighbor,leakix,massdns,naabu,ntlm,nuclei,otx,passivetotal,pgp,rapiddns,riddler,securitytrails,shodan_dns,skymem,smuggler,sslcert,sublist3r,telerik,threatminer,url_manipulation,urlscan,vhost,viewdns,virustotal,wappalyzer,wayback,zoomeye\n  -l, --list-modules    List available modules.\n  -em MODULE [MODULE ...], --exclude-modules MODULE [MODULE ...]\n                        Exclude these modules.\n  -f FLAG [FLAG ...], --flags FLAG [FLAG ...]\n                        Enable modules by flag. Choices: active,affiliates,aggressive,brute-force,cloud-enum,deadly,email-enum,iis-shortnames,passive,portscan,report,safe,slow,subdomain-enum,web-advanced,web-basic,web-paramminer,web-screenshots\n  -rf FLAG [FLAG ...], --require-flags FLAG [FLAG ...]\n                        Disable modules that don\'t have these flags (e.g. --require-flags passive)\n  -ef FLAG [FLAG ...], --exclude-flags FLAG [FLAG ...]\n                        Disable modules with these flags. (e.g. --exclude-flags brute-force)\n  -om MODULE [MODULE ...], --output-modules MODULE [MODULE ...]\n                        Output module(s). Choices: asset_inventory,csv,http,human,json,neo4j,python,websocket\n  -o DIR, --output-dir DIR\n  -c [CONFIG ...], --config [CONFIG ...]\n                        custom config file, or configuration options in key=value format: \'modules.shodan.api_key=1234\'\n  --allow-deadly        Enable the use of highly aggressive modules\n  -v, --verbose         Be more verbose\n  -d, --debug           Enable debugging\n  -s, --silent          Be quiet\n  --force               Run scan even if module setups fail\n  -y, --yes             Skip scan confirmation prompt\n  --dry-run             Abort before executing scan\n  --current-config      Show current config in YAML format\n\nTarget:\n  -t TARGET [TARGET ...], --targets TARGET [TARGET ...]\n                        Targets to seed the scan\n  -w WHITELIST [WHITELIST ...], --whitelist WHITELIST [WHITELIST ...]\n                        What\'s considered in-scope (by default it\'s the same as --targets)\n  -b BLACKLIST [BLACKLIST ...], --blacklist BLACKLIST [BLACKLIST ...]\n                        Don\'t touch these things\n  --strict-scope        Don\'t consider subdomains of target/whitelist to be in-scope\n\nWord cloud:\n  Save/load wordlist of common words gathered during a scan\n\n  --save-wordcloud FILE\n                        Output wordcloud to custom file when the scan completes\n  --load-wordcloud FILE\n                        Load wordcloud from a custom file\n\nModule dependencies:\n  Control how modules install their dependencies\n\n  --no-deps             Don\'t install module dependencies\n  --force-deps          Force install all module dependencies\n  --retry-deps          Try again to install failed module dependencies\n  --ignore-failed-deps  Run modules even if they have failed dependencies\n  --install-all-deps    Install dependencies for all modules\n\nAgent:\n  Report back to a central server\n\n  -a, --agent-mode      Start in agent mode\n\nMisc:\n  --version             show BBOT version and exit\n~~~\n\n# BBOT Config\nBBOT loads its config from these places in the following order:\n\n- `~/.config/bbot/bbot.yml` <-- Use this one as your main config\n- `~/.config/bbot/secrets.yml` <-- Use this one for sensitive stuff like API keys\n- command line (`--config`)\n\nThese config files will be automatically created for you when you first run BBOT.\n\nCommand-line arguments take precedence over all others. You can give BBOT a custom config file with `--config myconf.yml`, or individual arguments like this: `--config http_proxy=http://127.0.0.1:8080 modules.shodan_dns.api_key=1234`. To display the full and current BBOT config, including any command-line arguments, use `bbot --current-config`.\n\nNote that placing the following in `bbot.yml`:\n```yaml\nmodules:\n  shodan:\n    api_key: deadbeef\n```\nIs the same as:\n```bash\nbbot --config modules.shodan.api_key=deadbeef\n```\n\nFor explanations of config options, see `defaults.yml` or the [wiki](https://github.com/blacklanternsecurity/bbot/wiki#yaml-config)\n\n# Modules\n\n### Note: You can find more fun and interesting modules at the [Module Playground](https://github.com/blacklanternsecurity/bbot-module-playground). For instructions on how to install these other modules, see the [wiki](https://github.com/blacklanternsecurity/bbot/wiki#module-playground).\n\nTo view a full list of module config options, use `--help-all`.\n\n~~~\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| Module           | Type     | Needs   | Description                              | Flags                                   | Produced Events                          |\n|                  |          | API     |                                          |                                         |                                          |\n|                  |          | Key     |                                          |                                         |                                          |\n+==================+==========+=========+==========================================+=========================================+==========================================+\n| aspnet_viewstate | scan     |         | Parse web pages for viewstates and check | active,safe,web-basic                   | VULNERABILITY                            |\n|                  |          |         | them against blacklist3r                 |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| bucket_aws       | scan     |         | Check for S3 buckets related to target   | active,cloud-enum,safe                  | STORAGE_BUCKET                           |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| bucket_azure     | scan     |         | Check for Azure storage blobs related to | active,cloud-enum,safe                  | STORAGE_BUCKET                           |\n|                  |          |         | target                                   |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| bucket_gcp       | scan     |         | Check for Google object storage related  | active,cloud-enum,safe                  | STORAGE_BUCKET                           |\n|                  |          |         | to target                                |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| bypass403        | scan     |         | Check 403 pages for common bypasses      | active,aggressive,web-advanced          | FINDING                                  |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| cookie_brute     | scan     |         | Check for common HTTP cookie parameters  | active,aggressive,brute-force,slow,web- | FINDING                                  |\n|                  |          |         |                                          | paramminer                              |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| dnszonetransfer  | scan     |         | Attempt DNS zone transfers               | active,safe,subdomain-enum              | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| ffuf             | scan     |         | A fast web fuzzer written in Go          | active,aggressive,brute-                | URL                                      |\n|                  |          |         |                                          | force,deadly,web-advanced               |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| ffuf_shortnames  | scan     |         | Use ffuf in combination IIS shortnames   | active,aggressive,brute-force,iis-      | URL                                      |\n|                  |          |         |                                          | shortnames,web-advanced                 |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| generic_ssrf     | scan     |         | Check for generic SSRFs                  | active,aggressive,web-advanced          | VULNERABILITY                            |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| getparam_brute   | scan     |         | Check for common HTTP GET parameters     | active,aggressive,brute-force,slow,web- | FINDING                                  |\n|                  |          |         |                                          | paramminer                              |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| gowitness        | scan     |         | Take screenshots of webpages             | active,safe,web-screenshots             | SCREENSHOT                               |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| header_brute     | scan     |         | Check for common HTTP header parameters  | active,aggressive,brute-force,slow,web- | FINDING                                  |\n|                  |          |         |                                          | paramminer                              |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| host_header      | scan     |         | Try common HTTP Host header spoofing     | active,aggressive,web-advanced          | FINDING                                  |\n|                  |          |         | techniques                               |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| httpx            | scan     |         | Visit webpages. Many other modules rely  | active,safe,web-basic                   | HTTP_RESPONSE,URL                        |\n|                  |          |         | on httpx                                 |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| hunt             | scan     |         | Watch for commonly-exploitable HTTP      | active,safe,web-advanced                | FINDING                                  |\n|                  |          |         | parameters                               |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| iis_shortnames   | scan     |         | Check for IIS shortname vulnerability    | active,iis-shortnames,safe,web-basic    | URL_HINT                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| naabu            | scan     |         | Execute port scans with naabu            | active,aggressive,portscan              | OPEN_TCP_PORT                            |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| ntlm             | scan     |         | Watch for HTTP endpoints that support    | active,safe,web-basic                   | DNS_NAME,FINDING                         |\n|                  |          |         | NTLM authentication                      |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| nuclei           | scan     |         | Fast and customisable vulnerability      | active,aggressive,deadly,web-advanced   | FINDING,VULNERABILITY                    |\n|                  |          |         | scanner                                  |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| smuggler         | scan     |         | Check for HTTP smuggling                 | active,aggressive,brute-force,slow,web- | FINDING                                  |\n|                  |          |         |                                          | advanced                                |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| sslcert          | scan     |         | Visit open ports and retrieve SSL        | active,affiliates,email-                | DNS_NAME,EMAIL_ADDRESS                   |\n|                  |          |         | certificates                             | enum,safe,subdomain-enum                |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| telerik          | scan     |         | Scan for critical Telerik                | active,aggressive,slow,web-basic        | FINDING,VULNERABILITY                    |\n|                  |          |         | vulnerabilities                          |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| url_manipulation | scan     |         | Attempt to identify URL parsing/routing  | active,aggressive,web-advanced          | FINDING                                  |\n|                  |          |         | based vulnerabilities                    |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| vhost            | scan     |         | Fuzz for virtual hosts                   | active,aggressive,brute-                | DNS_NAME,VHOST                           |\n|                  |          |         |                                          | force,deadly,slow,web-advanced          |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| wappalyzer       | scan     |         | Extract technologies from web responses  | active,safe,web-basic                   | TECHNOLOGY                               |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| affiliates       | scan     |         | Summarize affiliate domains at the end   | passive,report,safe                     |                                          |\n|                  |          |         | of a scan                                |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| anubisdb         | scan     |         | Query jldc.me\'s database for subdomains  | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| asn              | scan     |         | Query ripe and bgpview.io for ASNs       | passive,report,safe,subdomain-enum      | ASN                                      |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| azure_tenant     | scan     |         | Query Azure for tenant sister domains    | affiliates,passive,safe,subdomain-enum  | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| bevigil          | scan     | X       | Retrieve OSINT data from mobile          | passive,safe,subdomain-enum             | DNS_NAME,URL_UNVERIFIED                  |\n|                  |          |         | applications using BeVigil               |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| binaryedge       | scan     | X       | Query the BinaryEdge API                 | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| builtwith        | scan     | X       | Query Builtwith.com for subdomains       | affiliates,passive,safe,subdomain-enum  | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| c99              | scan     | X       | Query the C99 API for subdomains         | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| censys           | scan     | X       | Query the Censys API                     | email-enum,passive,safe,subdomain-enum  | DNS_NAME,EMAIL_ADDRESS,IP_ADDRESS,OPEN_P |\n|                  |          |         |                                          |                                         | ORT,PROTOCOL                             |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| certspotter      | scan     |         | Query Certspotter\'s API for subdomains   | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| crobat           | scan     |         | Query Project Crobat for subdomains      | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| crt              | scan     |         | Query crt.sh (certificate transparency)  | passive,safe,subdomain-enum             | DNS_NAME                                 |\n|                  |          |         | for subdomains                           |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| dnscommonsrv     | scan     |         | Check for common SRV records             | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| dnsdumpster      | scan     |         | Query dnsdumpster for subdomains         | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| emailformat      | scan     |         | Query email-format.com for email         | email-enum,passive,safe                 | EMAIL_ADDRESS                            |\n|                  |          |         | addresses                                |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| fullhunt         | scan     | X       | Query the fullhunt.io API for subdomains | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| github           | scan     | X       | Query Github\'s API for related           | passive,safe,subdomain-enum             | URL_UNVERIFIED                           |\n|                  |          |         | repositories                             |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| hackertarget     | scan     |         | Query the hackertarget.com API for       | passive,safe,subdomain-enum             | DNS_NAME                                 |\n|                  |          |         | subdomains                               |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| hunterio         | scan     | X       | Query hunter.io for emails               | email-enum,passive,safe,subdomain-enum  | DNS_NAME,EMAIL_ADDRESS,URL_UNVERIFIED    |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| ipneighbor       | scan     |         | Look beside IPs in their surrounding     | aggressive,passive,subdomain-enum       | IP_ADDRESS                               |\n|                  |          |         | subnet                                   |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| leakix           | scan     |         | Query leakix.net for subdomains          | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| massdns          | scan     |         | Brute-force subdomains with massdns      | aggressive,brute-                       | DNS_NAME                                 |\n|                  |          |         | (highly effective)                       | force,passive,slow,subdomain-enum       |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| otx              | scan     |         | Query otx.alienvault.com for subdomains  | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| passivetotal     | scan     | X       | Query the PassiveTotal API for           | passive,safe,subdomain-enum             | DNS_NAME                                 |\n|                  |          |         | subdomains                               |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| pgp              | scan     |         | Query common PGP servers for email       | email-enum,passive,safe                 | EMAIL_ADDRESS                            |\n|                  |          |         | addresses                                |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| rapiddns         | scan     |         | Query rapiddns.io for subdomains         | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| riddler          | scan     |         | Query riddler.io for subdomains          | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| securitytrails   | scan     | X       | Query the SecurityTrails API for         | passive,safe,subdomain-enum             | DNS_NAME                                 |\n|                  |          |         | subdomains                               |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| shodan_dns       | scan     | X       | Query Shodan for subdomains              | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| skymem           | scan     |         | Query skymem.info for email addresses    | email-enum,passive,safe                 | EMAIL_ADDRESS                            |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| sublist3r        | scan     |         | Query sublist3r\'s API for subdomains     | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| threatminer      | scan     |         | Query threatminer\'s API for subdomains   | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| urlscan          | scan     |         | Query urlscan.io for subdomains          | passive,safe,subdomain-enum             | DNS_NAME,URL_UNVERIFIED                  |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| viewdns          | scan     |         | Query viewdns.info\'s reverse whois for   | affiliates,passive,safe                 | DNS_NAME                                 |\n|                  |          |         | related domains                          |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| virustotal       | scan     | X       | Query VirusTotal\'s API for subdomains    | passive,safe,subdomain-enum             | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| wayback          | scan     |         | Query archive.org\'s API for subdomains   | passive,safe,subdomain-enum             | DNS_NAME,URL_UNVERIFIED                  |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| zoomeye          | scan     | X       | Query ZoomEye\'s API for subdomains       | affiliates,passive,safe,subdomain-enum  | DNS_NAME                                 |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| asset_inventory  | output   |         | Output to an asset inventory style       |                                         |                                          |\n|                  |          |         | flattened CSV file                       |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| csv              | output   |         | Output to CSV                            |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| http             | output   |         | Output to HTTP                           |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| human            | output   |         | Output to text                           |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| json             | output   |         | Output to JSON                           |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| neo4j            | output   |         | Output to Neo4j                          |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| python           | output   |         | Output via Python API                    |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| websocket        | output   |         | Output to websockets                     |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| aggregate        | internal |         | Report on scan statistics                | passive,safe                            | SUMMARY                                  |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| excavate         | internal |         | Passively extract juicy tidbits from     | passive                                 | URL_UNVERIFIED                           |\n|                  |          |         | scan data                                |                                         |                                          |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n| speculate        | internal |         | Derive certain event types from others   | passive                                 | DNS_NAME,FINDING,IP_ADDRESS,OPEN_TCP_POR |\n|                  |          |         | by common sense                          |                                         | T                                        |\n+------------------+----------+---------+------------------------------------------+-----------------------------------------+------------------------------------------+\n~~~\n\n# Credit\n\nBBOT is written by @TheTechromancer. Web hacking in BBOT is made possible by @liquidsec, who wrote most of the web-oriented modules and helpers.\n\nVery special thanks to the following people who made BBOT possible:\n\n- @kerrymilan for his Neo4j and Ansible expertise\n- Steve Micallef (@smicallef) for creating Spiderfoot, by which BBOT is heavily inspired\n- Aleksei Kornev (@alekseiko) for allowing us ownership of the bbot Pypi repository <3\n',
    'author': 'TheTechromancer',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/blacklanternsecurity/bbot',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
